AdaptiveItem class
- Available extensions
Constructors
- AdaptiveItem({double? height, Widget? content, Color? bgColor = Colors.transparent, double? width})
Properties
- asWidget → Widget
-
Available on AdaptiveItem, provided by the AdaptiveWidget extension
no setter - bgColor → Color?
-
final
- content → Widget?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- width → double?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited